@@ -221,7 +221,7 @@ const reEscapeSequence = /\\([0-9A-Fa-f]+ |.)/g;
 // Generic filters can only be enforced once the main document is loaded.
 // Specific filers can be enforced before the main document is loaded.
 
-const FilterContainer = function() {
+const CosmeticFilteringEngine = function() {
     this.reSimpleHighGeneric = /^(?:[a-z]*\[[^\]]+\]|\S+)$/;
 
     this.selectorCache = new Map();
@@ -269,7 +269,7 @@ const FilterContainer = function() {
 
 // Reset all, thus reducing to a minimum memory footprint of the context.
 
-FilterContainer.prototype.reset = function() {
+CosmeticFilteringEngine.prototype.reset = function() {
     this.frozen = false;
     this.acceptedCount = 0;
     this.discardedCount = 0;
@@ -292,12 +292,12 @@ FilterContainer.prototype.reset = function() {
     this.highlyGeneric.complex.str = '';
     this.highlyGeneric.complex.mru.reset();
 
-    this.selfieVersion = 1;
+    this.selfieVersion = 2;
 };
 
 /******************************************************************************/
 
-FilterContainer.prototype.freeze = function() {
+CosmeticFilteringEngine.prototype.freeze = function() {
     this.duplicateBuster.clear();
     this.specificFilters.collectGarbage();
 
@@ -311,7 +311,7 @@ FilterContainer.prototype.freeze = function() {
 
 /******************************************************************************/
 
-FilterContainer.prototype.compile = function(parser, writer) {
+CosmeticFilteringEngine.prototype.compile = function(parser, writer) {
     if ( parser.hasOptions() === false ) {
         this.compileGenericSelector(parser, writer);
         return true;
@@ -337,7 +337,7 @@ FilterContainer.prototype.compile = function(parser, writer) {
 
 /******************************************************************************/
 
-FilterContainer.prototype.compileGenericSelector = function(parser, writer) {
+CosmeticFilteringEngine.prototype.compileGenericSelector = function(parser, writer) {
     if ( parser.isException() ) {
         this.compileGenericUnhideSelector(parser, writer);
     } else {
@@ -347,7 +347,7 @@ FilterContainer.prototype.compileGenericSelector = function(parser, writer) {
 
 /******************************************************************************/
 
-FilterContainer.prototype.compileGenericHideSelector = function(
+CosmeticFilteringEngine.prototype.compileGenericHideSelector = function(
     parser,
     writer
 ) {
@@ -403,7 +403,7 @@ FilterContainer.prototype.compileGenericHideSelector = function(
 
 /******************************************************************************/
 
-FilterContainer.prototype.compileGenericUnhideSelector = function(
+CosmeticFilteringEngine.prototype.compileGenericUnhideSelector = function(
     parser,
     writer
 ) {
@@ -432,7 +432,7 @@ FilterContainer.prototype.compileGenericUnhideSelector = function(
 
 /******************************************************************************/
 
-FilterContainer.prototype.compileSpecificSelector = function(
+CosmeticFilteringEngine.prototype.compileSpecificSelector = function(
     parser,
     hostname,
     not,
@@ -471,7 +471,7 @@ FilterContainer.prototype.compileSpecificSelector = function(
 
 /******************************************************************************/
 
-FilterContainer.prototype.fromCompiledContent = function(reader, options) {
+CosmeticFilteringEngine.prototype.fromCompiledContent = function(reader, options) {
     if ( options.skipCosmetic ) {
         this.skipCompiledContent(reader, 'SPECIFIC');
         this.skipCompiledContent(reader, 'GENERIC');
@@ -560,7 +560,7 @@ FilterContainer.prototype.fromCompiledContent = function(reader, options) {
 
 /******************************************************************************/
 
-FilterContainer.prototype.skipCompiledContent = function(reader, sectionId) {
+CosmeticFilteringEngine.prototype.skipCompiledContent = function(reader, sectionId) {
     reader.select(`COSMETIC_FILTERS:${sectionId}`);
     while ( reader.next() ) {
         this.acceptedCount += 1;
@@ -570,21 +570,23 @@ FilterContainer.prototype.skipCompiledContent = function(reader, sectionId) {
 
 /******************************************************************************/
 
-FilterContainer.prototype.toSelfie = function() {
+CosmeticFilteringEngine.prototype.toSelfie = function() {
     return {
         version: this.selfieVersion,
         acceptedCount: this.acceptedCount,
         discardedCount: this.discardedCount,
         specificFilters: this.specificFilters.toSelfie(),
-        lowlyGeneric: Array.from(this.lowlyGeneric),
-        highSimpleGenericHideArray: Array.from(this.highlyGeneric.simple.dict),
-        highComplexGenericHideArray: Array.from(this.highlyGeneric.complex.dict),
+        lowlyGeneric: this.lowlyGeneric,
+        highSimpleGenericHideDict: this.highlyGeneric.simple.dict,
+        highSimpleGenericHideStr: this.highlyGeneric.simple.str,
+        highComplexGenericHideDict: this.highlyGeneric.complex.dict,
+        highComplexGenericHideStr: this.highlyGeneric.complex.str,
     };
 };
 
 /******************************************************************************/
 
-FilterContainer.prototype.fromSelfie = function(selfie) {
+CosmeticFilteringEngine.prototype.fromSelfie = function(selfie) {
     if ( selfie.version !== this.selfieVersion ) {
         throw new Error(
             `cosmeticFilteringEngine: mismatched selfie version, ${selfie.version}, expected ${this.selfieVersion}`
@@ -593,17 +595,17 @@ FilterContainer.prototype.fromSelfie = function(selfie) {
     this.acceptedCount = selfie.acceptedCount;
     this.discardedCount = selfie.discardedCount;
     this.specificFilters.fromSelfie(selfie.specificFilters);
-    this.lowlyGeneric = new Map(selfie.lowlyGeneric);
-    this.highlyGeneric.simple.dict = new Set(selfie.highSimpleGenericHideArray);
-    this.highlyGeneric.simple.str = selfie.highSimpleGenericHideArray.join(',\n');
-    this.highlyGeneric.complex.dict = new Set(selfie.highComplexGenericHideArray);
-    this.highlyGeneric.complex.str = selfie.highComplexGenericHideArray.join(',\n');
+    this.lowlyGeneric = selfie.lowlyGeneric;
+    this.highlyGeneric.simple.dict = selfie.highSimpleGenericHideDict;
+    this.highlyGeneric.simple.str = selfie.highSimpleGenericHideStr;
+    this.highlyGeneric.complex.dict = selfie.highComplexGenericHideDict;
+    this.highlyGeneric.complex.str = selfie.highComplexGenericHideStr;
     this.frozen = true;
 };
 
 /******************************************************************************/
 
-FilterContainer.prototype.addToSelectorCache = function(details) {
+CosmeticFilteringEngine.prototype.addToSelectorCache = function(details) {
     const hostname = details.hostname;
     if ( typeof hostname !== 'string' || hostname === '' ) { return; }
     const selectors = details.selectors;
@@ -621,7 +623,7 @@ FilterContainer.prototype.addToSelectorCache = function(details) {
 
 /******************************************************************************/
 
-FilterContainer.prototype.removeFromSelectorCache = function(
+CosmeticFilteringEngine.prototype.removeFromSelectorCache = function(
     targetHostname = '*',
     type = undefined
 ) {
@@ -644,7 +646,7 @@ FilterContainer.prototype.removeFromSelectorCache = function(
 
 /******************************************************************************/
 
-FilterContainer.prototype.pruneSelectorCacheAsync = function() {
+CosmeticFilteringEngine.prototype.pruneSelectorCacheAsync = function() {
     if ( this.selectorCache.size <= this.selectorCacheCountMax ) { return; }
     const cache = this.selectorCache;
     const hostnames = Array.from(cache.keys())
@@ -658,7 +660,7 @@ FilterContainer.prototype.pruneSelectorCacheAsync = function() {
 
 /******************************************************************************/
 
-FilterContainer.prototype.disableSurveyor = function(details) {
+CosmeticFilteringEngine.prototype.disableSurveyor = function(details) {
     const hostname = details.hostname;
     if ( typeof hostname !== 'string' || hostname === '' ) { return; }
     const cacheEntry = this.selectorCache.get(hostname);
@@ -668,7 +670,7 @@ FilterContainer.prototype.disableSurveyor = function(details) {
 
 /******************************************************************************/
 
-FilterContainer.prototype.cssRuleFromProcedural = function(pfilter) {
+CosmeticFilteringEngine.prototype.cssRuleFromProcedural = function(pfilter) {
     if ( pfilter.cssable !== true ) { return; }
     const { tasks, action } = pfilter;
     let mq, selector;
@@ -699,7 +701,7 @@ FilterContainer.prototype.cssRuleFromProcedural = function(pfilter) {
 
 /******************************************************************************/
 
-FilterContainer.prototype.retrieveGenericSelectors = function(request) {
+CosmeticFilteringEngine.prototype.retrieveGenericSelectors = function(request) {
     if ( this.lowlyGeneric.size === 0 ) { return; }
     if ( Array.isArray(request.hashes) === false ) { return; }
     if ( request.hashes.length === 0 ) { return; }
@@ -757,7 +759,7 @@ FilterContainer.prototype.retrieveGenericSelectors = function(request) {
 
 /******************************************************************************/
 
-FilterContainer.prototype.retrieveSpecificSelectors = function(
+CosmeticFilteringEngine.prototype.retrieveSpecificSelectors = function(
     request,
     options
 ) {
@@ -928,7 +930,7 @@ FilterContainer.prototype.retrieveSpecificSelectors = function(
     if ( injectedCSS.length !== 0 ) {
         out.injectedCSS = injectedCSS.join('\n\n');
         details.code = out.injectedCSS;
-        if ( request.tabId !== undefined ) {
+        if ( request.tabId !== undefined && options.dontInject !== true ) {
             vAPI.tabs.insertCSS(request.tabId, details);
         }
     }
@@ -938,7 +940,7 @@ FilterContainer.prototype.retrieveSpecificSelectors = function(
         const networkFilters = [];
         if ( cacheEntry.retrieveNet(networkFilters) ) {
             details.code = `${networkFilters.join('\n')}\n{display:none!important;}`;
-            if ( request.tabId !== undefined ) {
+            if ( request.tabId !== undefined && options.dontInject !== true ) {
                 vAPI.tabs.insertCSS(request.tabId, details);
             }
         }
@@ -949,13 +951,13 @@ FilterContainer.prototype.retrieveSpecificSelectors = function(
 
 /******************************************************************************/
 
-FilterContainer.prototype.getFilterCount = function() {
+CosmeticFilteringEngine.prototype.getFilterCount = function() {
     return this.acceptedCount - this.discardedCount;
 };
 
 /******************************************************************************/
 
-FilterContainer.prototype.dump = function() {
+CosmeticFilteringEngine.prototype.dump = function() {
     const lowlyGenerics = [];
     for ( const selectors of this.lowlyGeneric.values() ) {
         lowlyGenerics.push(...selectors.split(',\n'));
@@ -976,7 +978,7 @@ FilterContainer.prototype.dump = function() {
 
 /******************************************************************************/
 
-const cosmeticFilteringEngine = new FilterContainer();
+const cosmeticFilteringEngine = new CosmeticFilteringEngine();
 
 export default cosmeticFilteringEngine;
 
