@@ -22,14 +22,10 @@
 
 // For background page
 
-/* globals browser */
-
-'use strict';
-
 /******************************************************************************/
 
-import webext from './webext.js';
 import { ubolog } from './console.js';
+import webext from './webext.js';
 
 /******************************************************************************/
 
@@ -47,6 +43,9 @@ if ( vAPI.canWASM === false ) {
 
 vAPI.supportsUserStylesheets = vAPI.webextFlavor.soup.has('user_stylesheet');
 
+const hasOwnProperty = (o, p) =>
+    Object.prototype.hasOwnProperty.call(o, p);
+
 /******************************************************************************/
 
 vAPI.app = {
@@ -109,9 +108,9 @@ vAPI.generateSecret = (size = 1) => {
  * 
  * */
 
-vAPI.sessionStorage = {
+vAPI.sessionStorage = browser.storage.session || {
     get() {
-        return Promise.resolve({});
+        return Promise.resolve();
     },
     set() {
         return Promise.resolve();
@@ -122,7 +121,7 @@ vAPI.sessionStorage = {
     clear() {
         return Promise.resolve();
     },
-    implemented: false,
+    unavailable: true,
 };
 
 /*******************************************************************************
@@ -137,46 +136,21 @@ vAPI.sessionStorage = {
 
 vAPI.storage = {
     get(key, ...args) {
-        if ( vAPI.sessionStorage.implemented !== true ) {
-            return webext.storage.local.get(key, ...args).catch(reason => {
-                console.log(reason);
-            });
-        }
-        return vAPI.sessionStorage.get(key, ...args).then(bin => {
-            const size = Object.keys(bin).length;
-            if ( size === 1 && typeof key === 'string' && bin[key] === null ) {
-                return {};
-            }
-            if ( size !== 0 ) { return bin; }
-            return webext.storage.local.get(key, ...args).then(bin => {
-                if ( bin instanceof Object === false ) { return bin; }
-                // Mirror empty result as null value in order to prevent
-                // from falling back to storage.local when there is no need.
-                const tomirror = Object.assign({}, bin);
-                if ( typeof key === 'string' && Object.keys(bin).length === 0 ) {
-                    Object.assign(tomirror, { [key]: null });
-                }
-                vAPI.sessionStorage.set(tomirror);
-                return bin;
-            }).catch(reason => {
-                console.log(reason);
-            });
+        return webext.storage.local.get(key, ...args).catch(reason => {
+            console.log(reason);
         });
     },
     set(...args) {
-        vAPI.sessionStorage.set(...args);
         return webext.storage.local.set(...args).catch(reason => {
             console.log(reason);
         });
     },
     remove(...args) {
-        vAPI.sessionStorage.remove(...args);
         return webext.storage.local.remove(...args).catch(reason => {
             console.log(reason);
         });
     },
     clear(...args) {
-        vAPI.sessionStorage.clear(...args);
         return webext.storage.local.clear(...args).catch(reason => {
             console.log(reason);
         });
@@ -216,9 +190,9 @@ vAPI.browserSettings = (( ) => {
 
         set: function(details) {
             for ( const setting in details ) {
-                if ( details.hasOwnProperty(setting) === false ) { continue; }
+                if ( hasOwnProperty(details, setting) === false ) { continue; }
                 switch ( setting ) {
-                case 'prefetching':
+                case 'prefetching': {
                     const enabled = !!details[setting];
                     if ( enabled ) {
                         bp.network.networkPredictionEnabled.clear({
@@ -234,9 +208,9 @@ vAPI.browserSettings = (( ) => {
                         vAPI.prefetching(enabled);
                     }
                     break;
-
-                case 'hyperlinkAuditing':
-                    if ( !!details[setting] ) {
+                }
+                case 'hyperlinkAuditing': {
+                    if ( details[setting] ) {
                         bp.websites.hyperlinkAuditingEnabled.clear({
                             scope: 'regular',
                         });
@@ -247,7 +221,7 @@ vAPI.browserSettings = (( ) => {
                         });
                     }
                     break;
-
+                }
                 case 'webrtcIPAddress': {
                     // https://github.com/uBlockOrigin/uBlock-issues/issues/1928
                     // https://www.reddit.com/r/uBlockOrigin/comments/sl7p74/
@@ -339,12 +313,12 @@ vAPI.Tabs = class {
             }
             this.onRemovedHandler(tabId, details);
         });
-     }
+    }
 
-    async executeScript() {
+    async executeScript(...args) {
         let result;
         try {
-            result = await webext.tabs.executeScript(...arguments);
+            result = await webext.tabs.executeScript(...args);
         }
         catch(reason) {
         }
@@ -458,22 +432,26 @@ vAPI.Tabs = class {
         // For some reasons, some platforms do not honor the left,top
         // position when specified. I found that further calling
         // windows.update again with the same position _may_ help.
+        //
+        // https://github.com/uBlockOrigin/uBlock-issues/issues/2249
+        //   Mind that the creation of the popup window might fail.
         if ( details.popup !== undefined && vAPI.windows instanceof Object ) {
-            const createDetails = {
+            const basicDetails = {
                 url: details.url,
                 type: details.popup,
             };
-            if ( details.box instanceof Object ) {
-                Object.assign(createDetails, details.box);
+            const shouldRestorePosition = details.box instanceof Object;
+            const extraDetails = shouldRestorePosition
+                ? Object.assign({}, basicDetails, details.box)
+                : basicDetails;
+            const win = await vAPI.windows.create(extraDetails);
+            if ( win === null ) {
+                if ( shouldRestorePosition === false ) { return; }
+                return vAPI.windows.create(basicDetails);
             }
-            const win = await vAPI.windows.create(createDetails);
-            if ( win === null ) { return; }
-            if ( details.box instanceof Object === false ) { return; }
-            if (
-                win.left === details.box.left &&
-                win.top === details.box.top
-            ) {
-                return;
+            if ( shouldRestorePosition === false ) { return; }
+            if ( win.left === details.box.left ) {
+                if ( win.top === details.box.top ) { return; }
             }
             vAPI.windows.update(win.id, {
                 left: details.box.left,
@@ -569,7 +547,7 @@ vAPI.Tabs = class {
             targetURL = vAPI.getURL(targetURL);
         }
 
-        vAPI.tabs.update(tabId, { url: targetURL });
+        return vAPI.tabs.update(tabId, { url: targetURL });
     }
 
     async remove(tabId) {
@@ -890,8 +868,8 @@ if ( webext.browserAction instanceof Object ) {
         const hasUnprocessedRequest = vAPI.net && vAPI.net.hasUnprocessedRequest(tabId);
         const { parts, state } = details;
         const { badge, color } = hasUnprocessedRequest
-                ? { badge: '!', color: '#FC0' }
-                : details;
+            ? { badge: '!', color: '#FC0' }
+            : details;
 
         if ( browserAction.setIcon !== undefined ) {
             if ( parts === undefined || (parts & 0b0001) !== 0 ) {
@@ -1050,7 +1028,7 @@ vAPI.messaging = {
             });
             break;
         }
-        case 'userCSS':
+        case 'userCSS': {
             if ( tabId === undefined ) { break; }
             const promises = [];
             if ( msg.add ) {
@@ -1081,6 +1059,9 @@ vAPI.messaging = {
             });
             break;
         }
+        default:
+            break;
+        }
     },
 
     // Use a wrapper to avoid closure and to allow reuse.
@@ -1238,7 +1219,7 @@ vAPI.Net = class {
         {
             const wrrt = browser.webRequest.ResourceType;
             for ( const typeKey in wrrt ) {
-                if ( wrrt.hasOwnProperty(typeKey) ) {
+                if ( hasOwnProperty(wrrt, typeKey) ) {
                     this.validTypes.add(wrrt[typeKey]);
                 }
             }
@@ -1541,10 +1522,7 @@ vAPI.localStorage = {
         if ( this.cache instanceof Promise ) { return this.cache; }
         if ( this.cache instanceof Object ) { return this.cache; }
         this.cache = vAPI.storage.get('localStorage').then(bin => {
-            this.cache = bin instanceof Object &&
-                bin.localStorage instanceof Object
-                    ? bin.localStorage
-                    : {};
+            this.cache = bin && bin.localStorage || {};
         });
         return this.cache;
     },
@@ -1671,10 +1649,7 @@ vAPI.cloud = (( ) => {
 
     const push = async function(details) {
         const { datakey, data, encode } = details;
-        if (
-            data === undefined ||
-            typeof data === 'string' && data === ''
-        ) {
+        if ( data === undefined || typeof data === 'string' && data === '' ) {
             return deleteChunks(datakey, 0);
         }
         const item = {
@@ -1682,10 +1657,9 @@ vAPI.cloud = (( ) => {
             tstamp: Date.now(),
             data,
         };
-        const json = JSON.stringify(item);
         const encoded = encode instanceof Function
-            ? await encode(json)
-            : json;
+            ? await encode(item)
+            : JSON.stringify(item);
 
         // Chunkify taking into account QUOTA_BYTES_PER_ITEM:
         //   https://developer.chrome.com/extensions/storage#property-sync
@@ -1750,13 +1724,16 @@ vAPI.cloud = (( ) => {
             i += 1;
         }
         encoded = encoded.join('');
-        const json = decode instanceof Function
-            ? await decode(encoded)
-            : encoded;
+
         let entry = null;
         try {
-            entry = JSON.parse(json);
-        } catch(ex) {
+            if ( decode instanceof Function ) {
+                entry = await decode(encoded) || null;
+            }
+            if ( typeof entry === 'string' ) {
+                entry = JSON.parse(entry);
+            }
+        } catch(_) {
         }
         return entry;
     };
@@ -1805,15 +1782,24 @@ vAPI.cloud = (( ) => {
 /******************************************************************************/
 /******************************************************************************/
 
-vAPI.alarms = browser.alarms || {
-    create() {
+vAPI.alarms = {
+    create(...args) {
+        webext.alarms.create(...args);
     },
-    clear() {
+    createIfNotPresent(name, ...args) {
+        webext.alarms.get(name).then(details => {
+            if ( details !== undefined ) { return; }
+            webext.alarms.create(name, ...args);
+        });
+    },
+    async clear(...args) {
+        return webext.alarms.clear(...args);
     },
     onAlarm: {
-        addListener() {
-        }
-    }
+        addListener(...args) {
+            webext.alarms.onAlarm.addListener(...args);
+        },
+    },
 };
 
 /******************************************************************************/
